@@ -14,7 +14,7 @@ import os
 import sys
 print(os.path.abspath('../..'))
 sys.path.insert(0, os.path.abspath('../..'))
-from qcware.version import parameter_api_version
+import qcware
 
 # -- Project information -----------------------------------------------------
 
@@ -22,7 +22,7 @@ project = 'qcware'
 copyright = '2019, QC Ware Corp.'
 author = 'Bryan E. Burr (bryan@qcware.com)'
 master_doc = 'index'
-version = parameter_api_version()
+version = qcware.__version__
 
 # -- General configuration ---------------------------------------------------
 
