@@ -15,9 +15,10 @@ class ApiCallResultUnavailableError(ApiException):
 
 
 class ApiCallExecutionError(ApiException):
-    def __init__(self, message, traceback):
+    def __init__(self, message, traceback, api_call_info=dict()):
         super().__init__(message)
         self.traceback = traceback
+        self.api_call_info = api_call_info
 
 
 class ApiTimeoutError(ApiException):
