@@ -4,8 +4,7 @@ from quasar import Circuit, CompositeGate, ControlledGate, Gate
 from qcware.util.serialize_quasar import (quasar_to_sequence,
                                           sequence_to_quasar, base_gate_name,
                                           num_adjoints, make_gate,
-                                          quasar_to_string,
-                                          string_to_quasar,
+                                          quasar_to_string, string_to_quasar,
                                           Canonical_gate_names)
 from scipy.stats import unitary_group
 
